@@ -2,9 +2,9 @@ import mimetypes
 import os
 from io import StringIO
 from django.http import HttpResponse, FileResponse, Http404
-from django.utils.translation import ugettext as _
-
-from jutil.format import format_xml
+from django.utils.translation import gettext as _
+from jutil.format import format_xml, format_xml_file
+import csv
 
 
 class FileSystemFileResponse(FileResponse):
@@ -37,8 +37,6 @@ class CsvFileResponse(HttpResponse):
         :param dialect: csv.writer dialect
         :param kw: Parameters to be passed to HttpResponse __init__
         """
-        import csv
-
         f = StringIO()
         writer = csv.writer(f, dialect=dialect)
         for row in rows:
@@ -51,7 +49,6 @@ class CsvFileResponse(HttpResponse):
 
 class FormattedXmlFileResponse(HttpResponse):
     def __init__(self, filename: str):
-        from jutil.format import format_xml_file
         content = format_xml_file(filename)
         super().__init__(content)
         self['Content-Type'] = 'application/xml'
@@ -61,7 +58,6 @@ class FormattedXmlFileResponse(HttpResponse):
 
 class FormattedXmlResponse(HttpResponse):
     def __init__(self, content: bytes, filename: str):
-        from jutil.format import format_xml_file
         content = format_xml(content)
         super().__init__(content)
         self['Content-Type'] = 'application/xml'
