@@ -3,11 +3,15 @@ import unicodedata
 from datetime import date
 from decimal import Decimal
 from random import randint
-
 from django.core.exceptions import ValidationError
 from django.utils.timezone import now
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from jutil.bank_const_iban import IBAN_LENGTH_BY_COUNTRY
+# Country-specific bank constants (abc-order):
+from jutil.bank_const_be import BE_BIC_BY_ACCOUNT_NUMBER, BE_BANK_NAME_BY_BIC
+from jutil.bank_const_dk import DK_BANK_CLEARING_MAP
+from jutil.bank_const_fi import FI_BIC_BY_ACCOUNT_NUMBER, FI_BANK_NAME_BY_BIC
+from jutil.bank_const_se import SE_BANK_CLEARING_LIST
 
 
 EMAIL_VALIDATOR = re.compile(r'[a-zA-Z0-9\._-]+@[a-zA-Z0-9\._-]+\.[a-zA-Z]+')
@@ -153,7 +157,7 @@ def iban_validator(v: str):
         raise ValidationError(_('Invalid IBAN account number') + ' ({}.1): {}'.format(country, v), code='invalid_iban')
 
 
-def validate_country_iban(v: str, country: str, length: int):
+def validate_country_iban(v: str, country: str):
     v = iban_filter(v)
     if v[0:2] != country:
         raise ValidationError(_('Invalid IBAN account number') + ' ({}.2): {}'.format(country, v), code='invalid_iban')
@@ -172,8 +176,7 @@ def iban_bank_info(v: str) -> (str, str):
     func = globals().get(func_name)
     if func is not None:
         return func(v)
-    else:
-        return '', ''
+    return '', ''
 
 
 def iban_bic(v: str) -> str:
@@ -186,21 +189,21 @@ def iban_bic(v: str) -> str:
     return info[0] if info else ''
 
 
-def calculate_age(born: date, today: date or None=None) -> int:
+def calculate_age(born: date, today: date or None = None) -> int:
     if not today:
         today = now().date()
     return today.year - born.year - ((today.month, today.day) < (born.month, born.day))
 
 
-def filter_country_company_reg_id(country_code: str, v: str):
+def filter_country_company_org_id(country_code: str, v: str):
     if country_code == 'FI':
-        return fi_company_reg_id_filter(v)
+        return fi_company_org_id_filter(v)
     return PASSPORT_FILTER.sub('', v)
 
 
-def validate_country_company_reg_id(country_code: str, v: str):
+def validate_country_company_org_id(country_code: str, v: str):
     if country_code == 'FI':
-        fi_company_reg_id_validator(v)
+        fi_company_org_id_validator(v)
 
 
 # ============================================================================
@@ -213,7 +216,7 @@ def validate_country_company_reg_id(country_code: str, v: str):
 # ----------------------------------------------------------------------------
 
 def be_iban_validator(v: str):
-    validate_country_iban(v, 'BE', IBAN_LENGTH_BY_COUNTRY.get('BE'))
+    validate_country_iban(v, 'BE')
 
 
 def be_iban_bank_info(v: str) -> (str, str):
@@ -222,7 +225,6 @@ def be_iban_bank_info(v: str) -> (str, str):
     :param v: IBAN account number
     :return: (BIC code, bank name) or ('', '') if not found
     """
-    from jutil.bank_const_be import BE_BIC_BY_ACCOUNT_NUMBER, BE_BANK_NAME_BY_BIC
     v = iban_filter(v)
     bic = BE_BIC_BY_ACCOUNT_NUMBER.get(v[4:7], None)
     return (bic, BE_BANK_NAME_BY_BIC[bic]) if bic is not None else ('', '')
@@ -233,11 +235,10 @@ def be_iban_bank_info(v: str) -> (str, str):
 # ----------------------------------------------------------------------------
 
 def dk_iban_validator(v: str):
-    validate_country_iban(v, 'DK', IBAN_LENGTH_BY_COUNTRY.get('DK'))
+    validate_country_iban(v, 'DK')
 
 
 def dk_clearing_code_bank_name(v: str) -> str:
-    from jutil.bank_const_dk import DK_BANK_CLEARING_MAP
     v = iban_filter(v)
     if v.startswith('DK'):
         v = v[4:]
@@ -259,7 +260,7 @@ def dk_iban_bank_info(v: str) -> (str, str):
 # ----------------------------------------------------------------------------
 
 def ee_iban_validator(v: str):
-    validate_country_iban(v, 'EE', IBAN_LENGTH_BY_COUNTRY.get('EE'))
+    validate_country_iban(v, 'EE')
 
 
 # ----------------------------------------------------------------------------
@@ -268,7 +269,7 @@ def ee_iban_validator(v: str):
 
 FI_SSN_FILTER = re.compile(r'[^-A-Z0-9]')
 FI_SSN_VALIDATOR = re.compile(r'^\d{6}[+-A]\d{3}[\d\w]$')
-FI_COMPANY_REG_ID_FILTER = re.compile(r'[^0-9]')
+FI_COMPANY_ORG_ID_FILTER = re.compile(r'[^0-9]')
 
 
 def fi_payment_reference_number(num: str):
@@ -317,7 +318,7 @@ def iso_payment_reference_validator(v: str):
 
 
 def fi_iban_validator(v: str):
-    validate_country_iban(v, 'FI', IBAN_LENGTH_BY_COUNTRY.get('FI'))
+    validate_country_iban(v, 'FI')
 
 
 def fi_iban_bank_info(v: str) -> (str, str):
@@ -326,7 +327,6 @@ def fi_iban_bank_info(v: str) -> (str, str):
     :param v: IBAN account number
     :return: (BIC code, bank name) or ('', '') if not found
     """
-    from jutil.bank_const_fi import FI_BIC_BY_ACCOUNT_NUMBER, FI_BANK_NAME_BY_BIC
     v = iban_filter(v)
     bic = FI_BIC_BY_ACCOUNT_NUMBER.get(v[4:7], None)
     return (bic, FI_BANK_NAME_BY_BIC[bic]) if bic is not None else ('', '')
@@ -336,30 +336,44 @@ def fi_ssn_filter(v: str) -> str:
     return FI_SSN_FILTER.sub('', v.upper())
 
 
-def fi_company_reg_id_filter(v: str) -> str:
-    v = FI_COMPANY_REG_ID_FILTER.sub('', v)
+def fi_company_org_id_filter(v: str) -> str:
+    v = FI_COMPANY_ORG_ID_FILTER.sub('', v)
     return v[:-1] + '-' + v[-1:] if len(v) >= 2 else ''
 
 
-def fi_company_reg_id_validator(v0: str) -> str:
-    v = fi_company_reg_id_filter(v0)
+def fi_company_org_id_validator(v0: str) -> str:
+    v = fi_company_org_id_filter(v0)
     prefix = v[:2]
     if v[-2:-1] != '-' and prefix != 'FI':
-        raise ValidationError(_('Invalid company registration ID')+' (FI.1): {}'.format(v0), code='invalid_company_reg_id')
+        raise ValidationError(_('Invalid company organization ID')+' (FI.1): {}'.format(v0), code='invalid_company_org_id')
     v = v.replace('-', '', 1)
     if len(v) != 8:
-        raise ValidationError(_('Invalid company registration ID')+' (FI.2): {}'.format(v0), code='invalid_company_reg_id')
+        raise ValidationError(_('Invalid company organization ID')+' (FI.2): {}'.format(v0), code='invalid_company_org_id')
     multipliers = (7, 9, 10, 5, 8, 4, 2)
     x = 0
     for i, m in enumerate(multipliers):
         x += int(v[i]) * m
-    quotient, remainder = divmod(x, 11)
+    remainder = divmod(x, 11)[1]
     if remainder == 1:
-        raise ValidationError(_('Invalid company registration ID')+' (FI.3): {}'.format(v0), code='invalid_company_reg_id')
+        raise ValidationError(_('Invalid company organization ID')+' (FI.3): {}'.format(v0), code='invalid_company_org_id')
     if remainder >= 2:
         check_digit = str(11 - remainder)
         if check_digit != v[-1:]:
-            raise ValidationError(_('Invalid company registration ID')+' (FI.4): {}'.format(v0), code='invalid_company_reg_id')
+            raise ValidationError(_('Invalid company organization ID')+' (FI.4): {}'.format(v0), code='invalid_company_org_id')
+
+
+def fi_company_org_id_generator() -> str:
+    remainder = 1
+    v = ''
+    while remainder < 2:
+        v = str(randint(11111111, 99999999))
+        multipliers = (7, 9, 10, 5, 8, 4, 2)
+        x = 0
+        for i, m in enumerate(multipliers):
+            x += int(v[i]) * m
+        remainder = divmod(x, 11)[1]
+    check_digit = str(11 - remainder)
+    return v[:-1] + '-' + check_digit
 
 
 def fi_ssn_validator(v: str):
@@ -372,9 +386,7 @@ def fi_ssn_validator(v: str):
         17: 'J', 	18: 'K', 	19: 'L', 	20: 'M', 	21: 'N', 	22: 'P', 	23: 'R',
         24: 'S', 	25: 'T', 	26: 'U', 	27: 'V', 	28: 'W', 	29: 'X', 	30: 'Y',
     }
-    ch = str(d)
-    if d in digits:
-        ch = digits[d]
+    ch = digits.get(d, str(d))
     if ch != v[-1:]:
         raise ValidationError(_('Invalid personal identification number')+' (FI.2): {}'.format(v), code='invalid_ssn')
 
@@ -391,9 +403,7 @@ def fi_ssn_generator():
         17: 'J', 	18: 'K', 	19: 'L', 	20: 'M', 	21: 'N', 	22: 'P', 	23: 'R',
         24: 'S', 	25: 'T', 	26: 'U', 	27: 'V', 	28: 'W', 	29: 'X', 	30: 'Y',
     }
-    ch = str(d)
-    if d in digits:
-        ch = digits[d]
+    ch = digits.get(d, str(d))
     return v + ch
 
 
@@ -413,7 +423,7 @@ def fi_ssn_birthday(v: str) -> date:
     return date(year, month, day)
 
 
-def fi_ssn_age(ssn: str, today: date or None=None) -> int:
+def fi_ssn_age(ssn: str, today: date or None = None) -> int:
     return calculate_age(fi_ssn_birthday(ssn), today)
 
 
@@ -426,7 +436,7 @@ SE_SSN_VALIDATOR = re.compile(r'^\d{6}[-]\d{3}[\d]$')
 
 
 def se_iban_validator(v: str):
-    validate_country_iban(v, 'SE', IBAN_LENGTH_BY_COUNTRY.get('SE'))
+    validate_country_iban(v, 'SE')
 
 
 def se_ssn_filter(v: str) -> str:
@@ -464,7 +474,6 @@ def se_clearing_code_bank_info(account_number: str) -> (str, int):
     :param account_number: Swedish account number with clearing code as prefix
     :return: (Bank name, account digit count) or ('', None) if not found
     """
-    from jutil.bank_const_se import SE_BANK_CLEARING_LIST
     v = digit_filter(account_number)
     clearing = v[:4]
     for name, begin, end, acc_digits in SE_BANK_CLEARING_LIST:
