@@ -1,7 +1,9 @@
-from xml.etree import ElementTree as ET
+# pylint: disable=too-many-arguments,too-many-locals
+from xml import etree
+from xml.etree.ElementTree import Element, SubElement
 
 
-def _xml_element_value(el: ET.Element, is_int: bool = False):
+def _xml_element_value(el: Element, is_int: bool = False):
     """
     Gets XML Element value.
     :param el: Element
@@ -15,7 +17,7 @@ def _xml_element_value(el: ET.Element, is_int: bool = False):
     try:
         if is_int:
             return int(el.text)
-    except:
+    except Exception:
         pass
     # default to str if not empty
     s = str(el.text).strip()
@@ -40,7 +42,7 @@ def _xml_tag_filter(s: str, strip_namespaces: bool) -> str:
     return s
 
 
-def _xml_set_element_data_r(data: dict, el: ET.Element, array_tags: list, int_tags: list,
+def _xml_set_element_data_r(data: dict, el: Element, array_tags: list, int_tags: list,
                             strip_namespaces: bool, parse_attributes: bool,
                             value_key: str, attribute_prefix: str):
 
@@ -83,7 +85,7 @@ def _xml_set_element_data_r(data: dict, el: ET.Element, array_tags: list, int_ta
         data[tag] = obj
 
 
-def xml_to_dict(xml_bytes: bytes, tags: list = [], array_tags: list = [], int_tags: list = [],
+def xml_to_dict(xml_bytes: bytes, tags: list or None = None, array_tags: list or None = None, int_tags: list or None = None,
                 strip_namespaces: bool = True, parse_attributes: bool = True,
                 value_key: str = '@', attribute_prefix: str = '@',
                 document_tag: bool = False) -> dict:
@@ -121,10 +123,18 @@ def xml_to_dict(xml_bytes: bytes, tags: list = [], array_tags: list = [], int_ta
 
     Returns: dict
     """
-    root = ET.fromstring(xml_bytes)
+    if tags is None:
+        tags = []
+    if array_tags is None:
+        array_tags = []
+    if int_tags is None:
+        int_tags = []
+
+    root = etree.ElementTree.fromstring(xml_bytes)
     if tags:
         if document_tag:
-            raise Exception('xml_to_dict: document_tag=True does not make sense when using selective tag list since selective tag list finds tags from the whole document, not only directly under root document tag')
+            raise Exception('xml_to_dict: document_tag=True does not make sense when using selective tag list '
+                            'since selective tag list finds tags from the whole document, not only directly under root document tag')
         root_elements = []
         for tag in tags:
             root_elements.extend(root.iter(tag))
@@ -145,7 +155,7 @@ def xml_to_dict(xml_bytes: bytes, tags: list = [], array_tags: list = [], int_ta
     return data if not document_tag else {root.tag: data}
 
 
-def _xml_element_set_data_r(el: ET.Element, data: dict, value_key: str, attribute_prefix: str):
+def _xml_element_set_data_r(el: Element, data: dict, value_key: str, attribute_prefix: str):
     # print('_xml_element_set_data_r({}): {}'.format(el.tag, data))
     if not hasattr(data, 'items'):
         data = {'@': data}
@@ -154,22 +164,22 @@ def _xml_element_set_data_r(el: ET.Element, data: dict, value_key: str, attribut
             el.text = str(v)
         elif k.startswith(attribute_prefix):
             el.set(k[1:], str(v))
-        elif isinstance(v, list) or isinstance(v, tuple):
+        elif isinstance(v, (list, tuple)):
             for v2 in v:
-                el2 = ET.SubElement(el, k)
-                assert isinstance(el2, ET.Element)
+                el2 = SubElement(el, k)
+                assert isinstance(el2, Element)
                 _xml_element_set_data_r(el2, v2, value_key, attribute_prefix)
         elif isinstance(v, dict):
-            el2 = ET.SubElement(el, k)
-            assert isinstance(el2, ET.Element)
+            el2 = SubElement(el, k)
+            assert isinstance(el2, Element)
             _xml_element_set_data_r(el2, v, value_key, attribute_prefix)
         else:
-            el2 = ET.SubElement(el, k)
-            assert isinstance(el2, ET.Element)
+            el2 = SubElement(el, k)
+            assert isinstance(el2, Element)
             el2.text = str(v)
 
 
-def dict_to_element(doc: dict, value_key: str='@', attribute_prefix: str='@') -> ET.Element:
+def dict_to_element(doc: dict, value_key: str = '@', attribute_prefix: str = '@') -> Element:
     """
     Generates XML Element from dict.
     Generates complex elements by assuming element attributes are prefixed with '@', and value is stored to plain '@'
@@ -207,7 +217,7 @@ def dict_to_element(doc: dict, value_key: str='@', attribute_prefix: str='@') ->
         raise Exception('Invalid data dict for XML generation, document root must have single element')
 
     for tag, data in doc.items():
-        el = ET.Element(tag)
-        assert isinstance(el, ET.Element)
+        el = Element(tag)
+        assert isinstance(el, Element)
         _xml_element_set_data_r(el, data, value_key, attribute_prefix)
         return el
